# -*- coding: utf-8 -*-
# @Created : maker
# @Time    : 1992
# @Project : chpypi
# @Software: PyCharm

proxiesKey = "wmzr5n8v"

# 代理服务器
proxyHost = "http-dyn.abuyun.com"
proxyPort = "9020"

# 代理隧道验证信息
proxyUser = "HKCK7DQ36X0862BD"
proxyPass = "BDA2D6665414DFB2"






