# -*- coding: utf-8 -*-
# @Created : maker
# @Time    : 1992
# @Project : chpypi
# @Software: PyCharm
import getproxies
import login












class HTTPTOOLS():
    def __init__(self):
        ...

    def login_chen_hai(self):
        return login.LOGIN

    def get_proxies(self):
        return getproxies.PROXIES






